/*============================================================================
  Summary:  Shows how Statistics are handled on UNIQUEIDENTIFIER columns.
------------------------------------------------------------------------------
  Written by Klaus Aschenbrenner, www.SQLpassion.at

  For more scripts and sample code, check out 
    http://www.SQLpassion.at

  THIS CODE AND INFORMATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF 
  ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED 
  TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
  PARTICULAR PURPOSE.
============================================================================*/

USE master
GO

CREATE DATABASE CustomersDatabase
GO

USE CustomersDatabase
GO

-- Create a new table with a UNIQUEIDENTIFIER column as primary key.
-- SQL Server will enforce the primary key constraint through unique clustered index in the background.
CREATE TABLE CustomersTableGuid
(
	ID UNIQUEIDENTIFIER NOT NULL PRIMARY KEY,
	FirstName VARCHAR(50),
	LastName VARCHAR(50)
)
GO

-- Insert 1000000 records
-- This takes around 4min.
DECLARE @i INT = 0
WHILE (@i <= 1000000)
BEGIN
	INSERT INTO CustomersTableGuid (ID, FirstName, LastName)
	VALUES
	(
		NEWID(),
		'FirstName' + CAST(@i AS VARCHAR),
		'LastName' + CAST(@i AS VARCHAR)
	)
	
	SET @i +=1
END
GO

-- Let's update the Statistics with a FULLSCAN.
UPDATE STATISTICS CustomersTableGuid WITH FULLSCAN
GO

-- When you look now into the Statistics object, you have *only* 3 steps in the Histogram.
DBCC SHOW_STATISTICS ('dbo.CustomersTableGuid', PK__Customer__3214EC271D07157F)
GO

-- Let's update the Statistics with a smaller sampling interval.
UPDATE STATISTICS CustomersTableGuid WITH SAMPLE 50 PERCENT
GO

-- When you look again into the Statistics object, you can see that
-- we have much *more* steps in the Histogram!
DBCC SHOW_STATISTICS ('dbo.CustomersTableGuid', PK__Customer__3214EC271D07157F)
GO

-- Clean up
USE master
GO

DROP DATABASE CustomersDatabase
GO